@@ -1,3 +1,5 @@
+import scattool
+
 from scattool.shared import ScatApp
 from pathlib import Path
 
@@ -31,3 +33,5 @@ class ScatCli(ScatApp):
         x = self.logs.list_logs()
         n, xx = x[0]
         print(self.logs.show_log(n))
+
+        print(self.get_version_identifier())
